# Notes / Warning :
# - this package is not prefixable
# - to update official patches, aka SOURCE4, see README.mdk in SOURCE4
# - as long as missing buildrequires is not identified, it must be manually built to get GUI

%define url ftp://ftp.vim.org/pub/vim/unix/
%define official_ptchlvl 127
%define rversion	7.2

%define perl_version %(rpm -q --qf '%%{epoch}:%%{version}' perl)
%define python_version %(rpm -q --qf '%%{epoch}:%%{version}' python)
%define ruby_version %(rpm -q --qf '%%{epoch}:%%{version}' ruby)

# Should we build X11 gui
%define buildgui 1

%{?_with_gui:%global buildgui 1}
%{?_without_gui:%global buildgui 0}

%define title       VI editor
%define longtitle   All-purpose text editor

Name:           vim
Version:        %{rversion}.%{official_ptchlvl}
Release:        %mkrel 8
Summary:        VIsual editor iMproved
Url:            http://www.vim.org/
License:        Charityware
Group:          Editors
Source0:        %{url}/%name-%rversion.tar.bz2
Source2:        %{url}/extra/%name-%rversion-lang.tar.bz2
# read README.mdk prior updating official patches:
Source3:		README.mdk
Source4:        vim-%rversion.%{official_ptchlvl}-patches.tar.bz2
# http://vim.sourceforge.net/scripts/script.php?script_id=98
Source5:        vim-spec-3.0.bz2
Source6:        http://trific.ath.cx/Ftp/vim/syntax/dhcpd.vim
# from apparmor-utils package
Source7:        apparmor.vim
Source8:        cfengine.vim
Source9:        nagios.vim
# MDK patches
Patch0:         vim-7.2-vimrc_nosetmouse.patch
Patch2:         vim-5.6a-paths.patch
Patch3:         vim-6.4-rpm-spec-syntax.patch
Patch8:         vim-6.0af-man-path.patch
Patch10:        xxd-locale.patch
Patch11:        vim-6.2-gcc31.patch
Patch20:        vimrc_hebrew.patch
Patch21:	    vim-7.2-perl-5.10-syntax.patch
Patch22:        vim-6.1-fix-xterms-comments.patch
Patch23:        vim-6.3-remove-docs.patch
Patch24:        vim-6.1-outline-mode.patch
Patch25:        vim-6.1-xterm-s-insert.patch
Patch26:        vim-7.0-changelog-mode.patch
Patch27:        vim-6.1-rpm42.patch
Patch28:        vim-7.2-po-mode.patch
Patch29:        vim-7.0-po-buildfix.patch
Patch30:        vim-7.0-add-dhcpd-syntax.patch
Patch31:	vim70-CVE-2007-2438.patch
Patch32:	vim-7.2-lzma-support.patch
Patch33:	vim-7.1.314-CVE-2009-0316-debian.patch

# Fedora patches
Patch100:  vim-7.0-fortify_warnings-1.patch
Patch101:  vim-7.2-fstabsyntax.patch
Patch102:  vim-7.1-lib64.patch

# (cg) Forking is handled very badly. The fork is handled after calling gtk_init()
# which can basically kill any threads started by gtk or any gtk modules including
# libcanberra. This is wrong, wrong, wrong, and gvim people should be shot.
# See https://qa.mandriva.com/show_bug.cgi?id=44925#c17
Patch1000: nofork.patch

BuildRequires:  python-devel
BuildRequires:  perl-devel
BuildRequires:  termcap-devel
BuildRequires:  acl-devel
%if %buildgui
BuildRequires:  libgnomeui2-devel ncurses-devel
BuildRequires:  libxt-devel
BuildRequires:  tcl
BuildRequires:  tcl-devel
%endif
BuildRoot:      %_tmppath/%name-%version

%description
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-common package
contains files which every VIM binary will need in order to run.

%package common
Summary:    The common files needed by any version of the VIM editor
Group:      Editors
Requires:   perl-base = %perl_version
Requires(pre):      coreutils
Requires(post):     coreutils
Requires(preun):    coreutils
Requires(postun):   coreutils
Conflicts:  man-pages-fr < 1.68.0-2mdk
Conflicts:  man-pages-it < 0.3.4-2mdk
Conflicts:  man-pages-pl <= 0.4-10mdk
Conflicts:  git-core < 1:1.6.0.1-2mdv

%description common
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-common package
contains files which every VIM binary will need in order to run.

%package minimal
Summary:    A minimal version of the VIM editor
Group:      Editors
Provides:   vim
Requires(post):     update-alternatives
Requires(postun):   update-alternatives

%description minimal
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-minimal package
includes a minimal version of VIM, which is installed into /bin/vi for use
when only the root partition is present.

%package enhanced
Summary:    A version of the VIM editor which includes recent enhancements
Group:      Editors
Requires:   vim-common >= %version
Obsoletes:  vim-color
Provides:   vim
Provides:   vim-color
Requires(post):     update-alternatives
Requires(postun):   update-alternatives

%description enhanced
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more.  The vim-enhanced package
contains a version of VIM with extra, recently introduced features like
Python and Perl interpreters.

Install the vim-enhanced package if you'd like to use a version of the VIM
editor which includes recently added enhancements like interpreters for the
Python and Perl scripting languages.  You'll also need to install the
vim-common package.

%if %buildgui
%package X11
Summary:    The VIM version of the vi editor for the X Window System
Group:      Editors
Provides:   vim
Requires:   vim-common >= %version
Requires(post):     desktop-file-utils
Requires(postun):   desktop-file-utils

%description X11
VIM (VIsual editor iMproved) is an updated and improved version of the vi
editor.  Vi was the first real screen-based editor for UNIX, and is still
very popular.  VIM improves on vi by adding new features: multiple windows,
multi-level undo, block highlighting and more. VIM-X11 is a version of the
VIM editor which will run within the X Window System.  If you install this
package, you can run VIM as an X application with a full GUI interface and
mouse support.

Install the vim-X11 package if you'd like to try out a version of vi with
graphics and mouse capabilities.  You'll also need to install the
vim-common package.
%endif

%define localedir %{buildroot}%{_datadir}/locale/

%prep
%setup -q -b 2 -n vim72 -a4
# spec plugin
rm -f runtime/doc/pi_spec.txt
rm -f runtime/ftpplugin/spec.vim
tar xfj %SOURCE5 -C runtime
cp -a %SOURCE6 runtime/syntax/
cp -a %SOURCE7 runtime/syntax/
cp -a %SOURCE8 runtime/syntax/
cp -a %SOURCE9 runtime/syntax/
#official patches
for i in vim-%version-patches/%{rversion}*; do
    patch -p0 -s < $i || { echo $i; exit 1; }
done

#mdk patches
%patch0 -p1 -b .vimrc_nosetmouse
%patch2 -p1
%patch3 -p0 -b .spec
%patch8 -p1 -b .manpath
%patch10 -p1 -b .xxdloc
#%patch11 -p1 -b .gcc31
%patch20 -p1 -b .warly
%patch21 -p1
%patch22 -p0
%patch23 -p0 -b .doc
%patch24 -p0
%patch25 -p0
%patch26 -p0
%patch27 -p0
%patch28 -p0
%patch29 -p0
%patch30 -p0
%patch32 -p1 -b .lzma_support
%patch33 -p1 -b .security

# Fedora patches
%patch100 -p1
%patch101 -p1
%patch102 -p1

%patch1000 -p1

perl -pi -e 's|SYS_VIMRC_FILE "\$VIM/vimrc"|SYS_VIMRC_FILE "%_sysconfdir/vim/vimrc"|' src/os_unix.h
perl -pi -e 's|SYS_GVIMRC_FILE "\$VIM/gvimrc"|SYS_GVIMRC_FILE "%_sysconfdir/vim/gvimrc"|' src/os_unix.h
# disable command echo
for i in runtime/{gvimrc_example.vim,vimrc_example.vim}; do
    perl -pi -e 's!^set showcmd!set noshowcmd!' $i
done
perl -pi -e 's|\Qsvn-commit.*.tmp\E|svn-commit*.tmp|'       ./runtime/filetype.vim

%build
# ensure xxd works with big files:
export CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64"
export CXXFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64"

%if %buildgui
# First build: gvim
LOCALEDIR=%localedir ./configure --prefix=%_prefix \
--enable-pythoninterp \
--enable-perlinterp \
--enable-rubyinterp \
--enable-tclinterp \
--with-features=huge \
--enable-acl --with-x=yes --enable-gui=gnome2 --exec-prefix=%_prefix/X11R6 \
--enable-gtk2-check \
--enable-multibyte --enable-xim --enable-fontset --mandir=%_mandir \
--libdir=%_libdir --with-compiledby="%packager"

echo "#define MAX_FEAT 1" >> src/config.h
echo "#define FEAT_GUI" >> src/config.h
# workaround buggy build system:
perl -pi -e 's!/usr/include long!/usr/include !' src/auto/config.mk

%make
mv src/vim src/gvim
make -C src clean
%endif

# Second build: vim-enhanced
./configure --prefix=%_prefix \
--enable-acl --enable-rubyinterp --enable-tclinterp --enable-pythoninterp --enable-perlinterp --with-features=huge \
--libdir=%_libdir --with-compiledby="%packager" \
--with-x=no --enable-gui=no --exec-prefix=%_prefix

%make
mv src/vim src/vim-enhanced
make -C src/ clean

# Third build: vim-minimal
./configure  --prefix=%_prefix \
--with-features=tiny --disable-tclinterp --disable-cscope --disable-multibyte \
--disable-hangulinput --disable-xim --disable-fontset --disable-gui \
--disable-acl --disable-pythoninterp --disable-perlinterp \
--libdir=%_libdir --with-compiledby="%packager" \
--with-x=no --enable-gui=no --exec-prefix=%_prefix --with-tlib=termcap --disable-gpm

%make
cp src/vim src/vim-minimal
%make -C src

cp -al runtime/doc doc
# apply os_doc.diff
pushd doc
rm -f *.1
rm -f os_{390,dos,msdos,risc,win32,amiga,mac,os2,beos,mint,qnx,vms}.txt
rm -f gui_{w16,w32}.txt
rm -f vim2html.pl Makefile *awk
popd

# britton support
ln -s tutor.fr runtime/tutor/tutor.br
ln -s menu_fr_fr.iso_8859-15.vim runtime/lang/menu_br

%install
rm -fr %{buildroot}

[ ! -e mandrake ] && mv vim-%version-patches mandrake

perl -pi -e 's!LOCALEDIR=\$\(DEST_LANG\)!LOCALEDIR=\$(DESTDIR)\$\(prefix\)/share/locale!g' src/Makefile

mkdir -p %{buildroot}{/bin,%_bindir,%_datadir/{vim,locale},%_mandir/man1,%localedir}
%makeinstall_std VIMRTDIR=""


make -C src installmacros prefix=%{buildroot}%_prefix VIMRTDIR=""

# fix unreadable files:
chmod a+r runtime/{autoload/{tar,netrw}.vim,doc/pi_{netrw,tar}.txt}

%if %buildgui
mkdir -p %{buildroot}%_bindir
install -s -m 755 src/gvim %{buildroot}%_bindir
%endif

install -s -m 755 src/vim-enhanced %{buildroot}%_bindir
install -s -m 755 src/vim-minimal %{buildroot}/bin/vim-minimal

cd %{buildroot}
rm -f ./bin/rvim
for i in ex vimdiff; do
    ln -sf vim-enhanced ./usr/bin/$i
done
rm -f ./usr/man/man1/rvim.*
%if %buildgui
ln -sf gvim ./usr/bin/gvimdiff
ln -sf gvim ./usr/bin/vimx
%endif
cd -

# installing man pages
for i in %{buildroot}%_mandir/man1/{vi,rvi}; do
    cp %{buildroot}%_mandir/man1/vim.1 $i.1
done

%if %buildgui
cp %{buildroot}%_mandir/man1/vim.1 %{buildroot}%_mandir/man1/gvim.1
%endif

ln -sf vimrc_example.vim %{buildroot}/usr/share/vim/vimrc

cd %{buildroot}/%_prefix/share/vim/tools
# i need to make a choice :(.
rm -f vim132
perl -p -i -e 's|#!/usr/bin/nawk|#!/usr/bin/gawk|' mve.awk
perl -p -i -e 's|#!/usr/local/bin/perl|#!/usr/bin/perl|' *.pl
perl -p -i -e 's|#!/usr/gnu/bin/perl|#!/usr/bin/perl|' *
cd -

# Be short-circuit aware :
ln -f runtime/macros/README.txt README_macros.txt
ln -f runtime/tools/README.txt README_tools.txt
perl -p -i -e "s|#!/usr/local/bin/perl|#!/usr/bin/perl|" runtime/doc/*.pl

# installing the menu icons & entry
%if %buildgui
mkdir -p %{buildroot}{%_miconsdir,%_liconsdir}
cp runtime/vim16x16.png %{buildroot}%_miconsdir/gvim.png
cp runtime/vim32x32.png %{buildroot}%_iconsdir/gvim.png
cp runtime/vim48x48.png %{buildroot}%_liconsdir/gvim.png

# menu entry
install -d -m 755 %{buildroot}%{_datadir}/applications
cat >  %{buildroot}%{_datadir}/applications/mandriva-%{name}-X11.desktop << EOF
[Desktop Entry]
Name=%{title}
Comment=%{longtitle}
Exec=%{_bindir}/gvim -f
Icon=gvim
Terminal=false
Type=Application
StartupNotify=false
Categories=Gtk;X-MandrivaLinux-MoreApplications-Editors;TextEditor;
MimeType=text/plain
EOF

# gvim and fontset (from Pablo) 2001/03/19
echo 'set guifontset=-*-fixed-medium-r-normal--14-*-*-*-c-*-*-*,-*-*-medium-r-normal--14-*-*-*-c-*-*-*,-*-*-medium-r-normal--14-*-*-*-m-*-*-*,*' > %{buildroot}%{_datadir}/vim/gvimrc
%endif

# fix the paths in the man pages
for i in %{buildroot}/usr/share/man/man1/*.1; do
    perl -p -i -e "s|%{buildroot}||" $i
done

# prevent including twice the doc
rm -fr %{buildroot}/usr/share/vim/doc
ln -sf ../../../%_defaultdocdir/%name-common/doc %{buildroot}/usr/share/vim/doc

# symlink locales in right place so that %find_land put needed %lang:
# see %pre common why this is needed
pushd %{buildroot}/%_datadir/vim/lang
    ln -s ../../locale/* .
popd

%{find_lang} %name

find %{buildroot}%_datadir/vim/ -name "tutor.*" | egrep -v 'tutor(|\.vim)$' |
 sed -e "s^%{buildroot}^^" -e 's!^\(.*tutor.\)\(..\)!%lang(\2) \1\2!g' >> %name.lang

find %{buildroot}%_datadir/vim/ -name "menu*" |
 sed -e "s^%{buildroot}^^" -e 's!^\(.*menu_\)\(..\)\(_\)!%lang(\2) \1\2\3!g' \
  -e 's!^\(.*menu\)\(_chinese\)!%lang(zh) \1\2!g' \
  -e 's!^\(.*menu\)\(_czech_\)!%lang(cs) \1\2!g' \
  -e 's!^\(.*menu\)\(_french\)!%lang(fr) \1\2!g' \
  -e 's!^\(.*menu\)\(_german\)!%lang(de) \1\2!g' \
  -e 's!^\(.*menu\)\(_japanes\)!%lang(ja) \1\2!g' \
  -e 's!^\(.*menu\)\(_polish\)!%lang(pl) \1\2!g' \
  -e 's!^\(.*menu\)\(_slovak\)!%lang(sk) \1\2!g' \
  -e 's!^\(.*menu\)\(_spanis\)!%lang(es) \1\2!g' \
  >> %name.lang
rm -f %{buildroot}%_bindir/vim

mkdir -p %{buildroot}/%_sysconfdir/vim/
MESSAGE='"Place your systemwide modification here.\n"%_datadir/vim/ files will be overwritten on update\n'
echo -e "$MESSAGE\nsource %_datadir/vim/vimrc" > %{buildroot}/%_sysconfdir/vim/vimrc
%if %buildgui
echo -e "$MESSAGE\nsource %_datadir/vim/gvimrc" > %{buildroot}/%_sysconfdir/vim/gvimrc
%endif

%pre common
# This is needed since locales have been moved to /usr/share/locale
# thus enabling us to install only requested locales
# the problem is that vim look for anything in %_datadir/vim/lang
# So we've to symlink locales there
# But to prevent update faillure, we must first be sure a link
# creation won't fail because old directory is still there
if test -d %_datadir/vim/lang -a ! -L %_datadir/vim/lang
then rm -fr %_datadir/vim/lang
else rm -f %_datadir/vim/lang
fi

%post minimal
update-alternatives --install /usr/bin/vi uvi /bin/vim-minimal 10
update-alternatives --install /bin/vi     vi  /bin/vim-minimal 10
update-alternatives --install /bin/vim    vim /bin/vim-minimal 10
for i in view ex rvi rview rvim; do
    update-alternatives --install /bin/$i $i /bin/vi 10 || :
done
:

%postun minimal
[ $1 = 0 ] || exit 0
update-alternatives --remove uvi /usr/bin/vim-minimal
update-alternatives --remove vi  /bin/vim-minimal
update-alternatives --remove vim /bin/vim-minimal

for i in view ex rvi rview rvim; do
    update-alternatives --remove $i /bin/$i || :
done

:

%triggerpostun -n vim-minimal -- vim-minimal < 6.1-22mdk
for i in view ex rvi rview rvim; do
    update-alternatives --remove $i /bin/$i || :
done

:


%post enhanced
update-alternatives --install /usr/bin/vi uvi /usr/bin/vim-enhanced 20
update-alternatives --install /bin/vi  vi     /usr/bin/vim-enhanced 20
update-alternatives --install /bin/vim vim    /usr/bin/vim-enhanced 20
:

%postun enhanced
[ $1 = 0 ] || exit 0
update-alternatives --remove uvi /usr/bin/vim-enhanced
update-alternatives --remove vi  /usr/bin/vim-enhanced
update-alternatives --remove vim /usr/bin/vim-enhanced
:
%if %buildgui
%if %mdkversion < 200900
%post X11
%{update_menus}
%{update_desktop_database}
%endif

%if %mdkversion < 200900
%postun X11
%{clean_menus}
%{clean_desktop_database}
%endif
%endif

%clean
rm -rf %{buildroot}

%files common -f vim.lang
%defattr(-,root,root)
%doc README*.txt runtime/termcap
%doc --parents mandrake/README*
%doc doc
%_datadir/vim/doc


%dir %_datadir/vim/
%_datadir/vim/[^g]*
%_datadir/vim/gvimrc_example.vim
%_mandir/man1/vim.1*
%_mandir/man1/ex.1*
%_mandir/man1/vi.1*
%_mandir/man1/view.1*
%_mandir/man1/rvi.1*
%_mandir/man1/rview.1*
%_mandir/man1/vimdiff.1*
%_mandir/man1/vimtutor.1*
%_mandir/man1/rvim.1*
%_mandir/*/man*/*
%lang(fr) %_mandir/fr*/man*/*
%lang(it) %_mandir/it*/man*/*
%lang(pl) %_mandir/pl*/man*/*
%lang(ru) %_mandir/ru*/man*/*
%exclude %_mandir/man1/evim.1*
%exclude %_bindir/rview
%exclude %_bindir/rvim
%exclude %_bindir/view
%_bindir/vimtutor
%_bindir/xxd
%_mandir/man1/xxd.1*
%_sysconfdir/vim/
%config(noreplace) %_sysconfdir/vim/*
# Cmake improved syntax provided by cmake package ( needed for syntax additions )
%exclude %_datadir/vim/*/cmake.vim

%files minimal
%defattr(-,root,root)
%doc README*.txt
/bin/vim-minimal

%files enhanced
%defattr(-,root,root)
%doc README*.txt
%_bindir/ex
%_bindir/vimdiff
%_bindir/vim-enhanced

%if %buildgui
%files X11
%defattr(-,root,root)
%doc README*.txt
%_bindir/gvim
%_bindir/gvimdiff
%_bindir/vimx
%_mandir/man1/gvim.1*
%_iconsdir/gvim.png
%_miconsdir/gvim.png
%_liconsdir/gvim.png
%_datadir/applications/mandriva-%{name}-X11.desktop
%_datadir/vim/gvimrc
%endif




%changelog
* Wed Mar 04 2009 Colin Guthrie <cguthrie@mandriva.org> 7.2.127-8mdv2009.1
+ Revision: 348709
- Do not fork gvim after initialising gtk (breaks lots of things) mdv#44925

* Wed Feb 25 2009 Thierry Vignaud <tvignaud@mandriva.com> 7.2.127-7mdv2009.1
+ Revision: 344641
- patch 33: security fix for CVE-2009-0316 (#48045)
- bump to official patchlevel 127

* Mon Feb 16 2009 Thierry Vignaud <tvignaud@mandriva.com> 7.2.108-6mdv2009.1
+ Revision: 340883
- bump to official patchlevel 108

* Mon Feb 02 2009 Jérôme Soyer <saispo@mandriva.org> 7.2.087-6mdv2009.1
+ Revision: 336345
- Revert to old patch from Fedora

* Sun Feb 01 2009 Jérôme Soyer <saispo@mandriva.org> 7.2.087-5mdv2009.1
+ Revision: 336102
- Really revert 087
- Revert to 87
- Bump Release
- Add python and ruby support for vim-enhanced

* Sun Feb 01 2009 Jérôme Soyer <saispo@mandriva.org> 7.2.087-4mdv2009.1
+ Revision: 336087
- Upgrade top 087 upstream patch
- Clean SPEC
- Fix lib64 for python interpreter

* Mon Jan 19 2009 Helio Chissini de Castro <helio@mandriva.com> 7.2.079-4mdv2009.1
+ Revision: 331250
- Cmake syntax files would be available by cmake own package. This solves current issue of not uptodate syntax new macro entries,
  as cmake is released more often than a vim release.

* Mon Jan 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 7.2.079-3mdv2009.1
+ Revision: 331225
- really add nagios syntax file

* Fri Jan 16 2009 Guillaume Rousse <guillomovitch@mandriva.org> 7.2.079-2mdv2009.1
+ Revision: 330280
- add nagios syntax file

* Wed Jan 07 2009 Thierry Vignaud <tvignaud@mandriva.com> 7.2.079-1mdv2009.1
+ Revision: 326714
- bump to official patchlevel 079

* Wed Dec 24 2008 Michael Scherer <misc@mandriva.org> 7.2.069-11mdv2009.1
+ Revision: 318354
- rebuild for new python

* Tue Dec 16 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.2.069-10mdv2009.1
+ Revision: 314751
- fix build
- bump to official patchlevel 069
- rediff some patches due to stricter rpm-4.6rc3
- include official patchlevel in version instead of release

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 7.2-9.065mdv2009.1
+ Revision: 311037
- rebuild for new tcl

  + Thierry Vignaud <tvignaud@mandriva.com>
    - source 3: restore README.mdk (explaining how to update to latest official
      patchlevel) from vim-7.0-14mdv2007.0.src.rpm since it disapeared between
      2007.0 & 2007.1

* Thu Dec 04 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.2-8.065mdv2009.1
+ Revision: 309911
- include official patchlevel in release number
- bump to official patchlevel 065

* Wed Sep 24 2008 Guillaume Rousse <guillomovitch@mandriva.org> 7.2-8mdv2009.0
+ Revision: 287822
- cfengine syntax file
- patch perl syntax file for 5.10 new keywords

* Wed Sep 17 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.2-7mdv2009.0
+ Revision: 285363
- bump to official patchlevel 018
- bump to official patchlevel 015

* Tue Sep 09 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.2-5mdv2009.0
+ Revision: 283113
- bump to official patchlevel 013
- fix unreadable files (#43598)

* Mon Sep 01 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.2-4mdv2009.0
+ Revision: 278469
- Restored/redid vimrc_nosetmouse patch for vim 7.2, it wasn't already
  applied.

* Fri Aug 29 2008 Pixel <pixel@mandriva.com> 7.2-3mdv2009.0
+ Revision: 277246
- really fix upgrading

* Thu Aug 28 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.2-2mdv2009.0
+ Revision: 276819
- fix upgrading

* Wed Aug 27 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.2-1mdv2009.0
+ Revision: 276566
- new release
- bump to official patchlevel 006
- drop patch 0 (merged upstream)
- rediff patch 28 & 32
- bump to official patchlevel 330

* Thu Aug 07 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.1-16mdv2009.0
+ Revision: 265771
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Wed Jun 11 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.1-15mdv2009.0
+ Revision: 218083
- bump to official patchlevel 314
- bump to official patchlevel 264
- do not require the whole perl

* Thu Feb 07 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.1-14mdv2008.1
+ Revision: 163557
- make xxd working with files larger than 2GB on ia32 (#37332)
- add patch 34: match more keywords in fstab
- update to official patchlevel 244
- buildrequires ncurses-devel, thus using ncurses instead of termcap (#37529)

* Wed Jan 30 2008 Thierry Vignaud <tvignaud@mandriva.com> 7.1-13mdv2008.1
+ Revision: 160321
- update to official patchlevel 242
- point the bogus patch on error

* Mon Jan 21 2008 Gustavo De Nardin <gustavodn@mandriva.com> 7.1-12mdv2008.1
+ Revision: 155887
- re-rebuild for perl-5.10.0 (unneeded, vim was just left half upgraded by urpmi)

* Mon Jan 14 2008 Pixel <pixel@mandriva.com> 7.1-11mdv2008.1
+ Revision: 151249
- rebuild for perl-5.10.0

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 7.1-10mdv2008.0
+ Revision: 82053
- rebuild for new soname of tcl

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Tue Aug 21 2007 Thierry Vignaud <tvignaud@mandriva.com> 7.1-9mdv2008.0
+ Revision: 68592
- fix file conflict (#32651)
- kill file require on update-alternatives
- update to officiel patch level 87
- fix man pages extension

* Wed Aug 15 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.1-8mdv2008.0
+ Revision: 63544
- fix crash

* Sun Jul 15 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.1-7mdv2008.0
+ Revision: 52224
- fix problems reading compressed files caused by fortify patch (update P33, fixes #31908)
- update to patch level 028 (S4)

* Fri Jul 13 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.1-6mdv2008.0
+ Revision: 51790
- replace buffer overflow patch (P33) with better from LFS

* Thu Jul 12 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.1-5mdv2008.0
+ Revision: 51636
- fix buffer overflow that caused vim to be crashed with fortify (P33)
- do parallell build
- more lzma support added (P32)
- add some lzma support (P32, work in progress)

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 7.1-4mdv2008.0
+ Revision: 45094
- recognize %%serverbuild when syntax highlighting

  + Michael Scherer <misc@mandriva.org>
    - fix documentation

* Mon Jun 25 2007 Thierry Vignaud <tvignaud@mandriva.com> 7.1-3mdv2008.0
+ Revision: 44064
- update to official patch 12

  + Andreas Hasenack <andreas@mandriva.com>
    - added apparmor syntax file

* Wed May 16 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.1-2mdv2008.0
+ Revision: 27371
- Added vimrc_nosetmouse patch, don't 'set mouse=a' by default, keep
  behaviour like old versions before 7.1, set mouse=a changes behavior
  of copy/paste with mouse on X.

* Tue May 15 2007 Nicolas Lécureuil <neoclust@mandriva.org> 7.1-1mdv2008.0
+ Revision: 26879
- New version

* Thu May 10 2007 Thierry Vignaud <tvignaud@mandriva.com> 7.0-19mdv2008.0
+ Revision: 26129
- bump release

* Thu May 10 2007 Thierry Vignaud <tvignaud@mandriva.com> 7.0-18mdv2008.0
+ Revision: 26112
- patch 31: security fix for CVE-2007-2438

* Thu Apr 19 2007 Nicolas Lécureuil <neoclust@mandriva.org> 7.0-17mdv2008.0
+ Revision: 14888
- Kill old debian style


* Thu Dec 21 2006 Thierry Vignaud <tvignaud@mandriva.com> 7.0-16mdv2007.0
+ Revision: 101032
- update up to official patchlevel 178

* Wed Dec 20 2006 Guillaume Rousse <guillomovitch@mandriva.org> 7.0-15mdv2007.1
+ Revision: 100514
- rebuild against latest python

  + Michael Scherer <misc@mandriva.org>
    - Import vim

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 7.0-14mdv2007.0
- Rebuild

* Tue Sep 12 2006 Guillaume Rousse <guillomovitch@mandriva.org> 7.0-13mdv2007.0
- buildrequires libxt-devel (should fix automatic rebuilds)

* Sat Sep 09 2006 Mandriva Linux Team <http://www.mandrivaexpert.com/> 7.0-12mdv2007.0
- Add missing }

* Thu Sep 07 2006 Frederic Crozat <fcrozat@mandriva.com> 7.0-11mdv2007.0
- Rebuild to get GUI back

* Sat Sep 02 2006 Guillaume Rousse <guillomovitch@mandriva.org> 7.0-10mdv2007.0
- add update-desktop-database call in %%post/%%postun

* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 7.0-9mdv2007.0
- rebuild manually on all architectures to get GUI...

* Sun Aug 27 2006 Nicolas Lcureuil <neoclust@mandriva.org> 7.0-8mdv2007.0
- Fix text/plain typo

* Fri Aug 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 7.0-7mdv2007.0
- drop usage of /usr/X11R6 tree
- xdg menu
- some spec cleanup

* Fri Jul 07 2006 Frederic Crozat <fcrozat@mandriva.com> 7.0-6mdv2007.0
- rebuild again to really get GUI working

* Mon Jun 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 7.0-5mdv2007.0
- rebuild to get GUI working

* Sat Jun 24 2006 Thierry Vignaud <tvignaud@mandriva.com> 7.0-4mdv2007.0
- update up to official patchlevel 30
- move the conflicts in common subpackage (#23068)
- patch 30: add colorization for dhcpd (#21129)
- source 3:
  o fix gvim not recognized as an editor in GNOME (#14228)
  o fix integration with Konqueror (#12331)

* Thu May 11 2006 Thierry Vignaud <tvignaud@mandriva.com> 7.0-3mdk
- fix harmless typo in conflict

* Thu May 11 2006 Thierry Vignaud <tvignaud@mandriva.com> 7.0-2mdk
- fix conflict with man-pages-{fr,it,pl}

* Wed May 10 2006 Thierry Vignaud <tvignaud@mandriva.com> 7.0-1mdk
- new release
- update up to official patchlevel 1
- update patch 26
- patch 29: fix build

* Thu Mar 09 2006 Thierry Vignaud <tvignaud@mandriva.com> 6.4-8mdk
- update up to official patchlevel 8
- enable ACL support for enhanced and X11 subpackages (#21447)

* Fri Jan 27 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 6.4-7mdk
- drop BuildRequires: tclx tclx-devel

* Tue Jan 24 2006 Oden Eriksson <oeriksson@mandriva.com> 6.4-6mdk
- rebuilt against perl-5.8.8

* Fri Jan 20 2006 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 6.4-5mdk
- Rebuild for new perl

* Sun Jan 01 2006 Oden Eriksson <oeriksson@mandriva.com> 6.4-4mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps

* Wed Oct 26 2005 Olivier Thauvin <nanardon@mandriva.org> 6.4-2mdk
- manual rebuild to have vim-X11 working on amd64

* Wed Oct 19 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 6.4-2mdk
- Fix vim syntax error in Patch 3
- Add gvimdiff symlink

* Tue Oct 18 2005 Thierry Vignaud <tvignaud@mandriva.com> 6.4-1mdk
- new release
- redo patches 3 & 28

* Sun Aug 07 2005 Olivier Thauvin <nanardon@mandriva.org> 6.3-21mdk
- rebuild manually on amd64 to have X11...

* Sat Aug 06 2005 Olivier Thauvin <nanardon@mandriva.org> 6.3-20mdk
- _try_ to ensure gvim is really build with x11 extension
  the problem occur when the bot build the spec
  (E25: GUI cannot be used: Not enabled at compile time)

* Sat Jul 30 2005 Thierry Vignaud <tvignaud@mandriva.com> 6.3-19mdk
- update up to official patchlevel 86

* Sat Jul 30 2005 Guillaume Rousse <guillomovitch@mandriva.org> 6.3-18mdk 
- update spec mode to 3.0, and add missing documentation

* Wed Jul 13 2005 Olivier Thauvin <nanardon@mandriva.org> 6.3-17mdk
- --enable-rubyinterp (Andre Nathan <andre@digirati.com.br>)
- --enable-tclinterp in same time

* Sun May 22 2005 Olivier Thauvin <nanardon@mandriva.org> 6.3-16mdk
- fix perl version eval

* Sat May 21 2005 Olivier Thauvin <nanardon@zarb.org> 6.3-15mdk
- fix spec mode (update patch 3)
- add --without gui

* Fri May 20 2005 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 6.3-14mdk
- Rebuild for new perl

* Tue Apr 19 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-13mdk
- update up to official patchlevel 71

* Wed Feb 16 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-12mdk
- update up to official patchlevel 62:
  o wrong text and crash using <C-R>= or <C-\>e in command line
  o window title wrong for specific multi-byte character
  o folds are not updated after a filter command
  o crash when zero columns room; can't compile without :vsplit
  o crash when editing a file with spaces and shell expansion
  o register name isn't checked for CTRL-R CTRL-O in Insert mode
  o display mess when multi-byte char at right edge of screen
  o ":normal! gQ" hangs

* Tue Feb 15 2005 Michael Scherer <misc@mandrake.org> 6.3-11mdk
- fix svn commit file detection

* Wed Feb 02 2005 Michael Scherer <misc@mandrake.org> 6.3-10mdk
- add missing BuildRequires ( python-devel )

* Tue Jan 11 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-9mdk
- update up to official patchlevel 54

* Tue Jan 04 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-8mdk
- update up to official patchlevel 53:
  o can't edit file with path separator in trail byte of last char
  o when <Space> is remapped abbreviations are not expanded
  o missing NUL for strings created with ga_concat()
  o (extra) missing NUL for list of server names
  o setting 'bg' in syncolor.vim may cause endless loop or crash
  o the BOM marker is written when appending to a file
  o crash in syntax highlighting code when inserting a line break
  o GTK 2: crash when 'enc' is set to "utf-8" and menus redefined
  o pressing Tab when entering a mapping may cause a display error
  o with Python 2.3 using threads doesn't work
  o mapping ending in two-char command doesn't restart Insert mode
  o ml_get errors when fold was deleted
  o (after 6.3.032) warning for unused variable
  o line numbers not updated when inserting a line above window
  o window count for a buffer was wrong after error handling
  o CTRL-X CTRL-E in Insert mode does not scroll fold correctly
  o 'hlsearch' highlighting sometimes disappears
  o some option values may cause trouble in a modeline
  o ":registers" doesn't show multi-byte characters correctly
  o (after 6.3.045) compiler warning for pointer type
  o a SIGHUP while already exiting may cause a crash
  o crash when 'wildmenu' set and completing multi-byte file name

* Sat Dec 04 2004 Michael Scherer <misc@mandrake.org> 6.3-7mdk
- Rebuild for new python

* Fri Nov 12 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 6.3-6mdk
- Rebuild for new perl

* Sat Sep 04 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-5mdk
- update up to official patchlevel 20:
  o default value of 'helplang' is wrong for Chinese and Taiwanese
  o the string returned by winrestcmd() may end in garbage
  o 'define' default had "\s" before #, breaks "[d"
  o "9zz" could place the cursor beyond the end of a line
  o ":0argadd zero" added the argument after the first one
  o crash during startup when compiled for debugging
  o "dw" doesn't work right for UTF-8 when 'delcombine' is set

* Tue Aug 17 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 6.3-4mdk
- Rebuild with new menu

* Wed Jul 21 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-3mdk
- update up to official patchlevel 13:
  o utf-8 detection in translated help files is wrong
  o crash when using console dialog without default choice
  o too many hit-enter prompts when searching for long string
  o crash when searching with character offset in closed fold
  o the current directory is prepended to the ":breakadd" argument
  o swap file is not deleted for a "nofile" buffer after ":cd"
  o writing to a named pipe causes an error message for fsync()
  o crash when user command completion uses "normal :cmd"
  o lalloc(0) error for substitute command with multi-line pattern
  o crash when using CTRL-R = in command line uses "normal :cmd"

* Thu Jul 08 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 6.3-2mdk
- Rebuild for new perl

* Fri Jun 11 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.3-1mdk
- new release
- disable command echo by default (olivier thauvin)
- renew patch 23
- update up to official patchlevel 181:
  o ":browse split" gives file selection dialog twice

* Wed May 05 2004 Luca Berra <bluca@vodka.it> 6.2-17mdk
- update source 5 and drop p29 (fix #6753)
- kill evim (evil vim) manpage, add rview symlink
- remove dangling symlinks in /usr/bin

* Wed May 05 2004 Michael Scherer <misc@mandrake.org> 6.2-16mdk
- fix #4688, by using a config file in /etc/

* Fri Apr 16 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 6.2-15mdk
- rebuild
- don't remove builddir in %%clean

* Wed Jan 07 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.2-14mdk
- update up to official patchlevel 180:
  o not all "find" versions accept "-or"
  o _Xmblen prototype still causes trouble
  o mouse click at hit-enter prompt only works in last line
  o setting 'backupext' in a *WritePre autocommand doesn't work
  o accented characters in help are not used in 'iskeyword'
  o VisVim: space in file name, random chars are executed
  o newbies can't figure out how to exit and try CTRL-C 
  o English message translations don't work
  o CVS directories still unecessarily installed
- source 5: spec mode from Guillaume Rousse

* Mon Jan 05 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 6.2-13mdk
- update up to official patchlevel 170:
  o "%%p" in 'errorformat' uses a wrong column number
  o configure doesn't get the right compile flags for Perl
  o "undo" in 'foldopen' doesn't work with expression folding
  o crash with 'virtualedit' and selecting double-wide character
  o ":redraw" doesn't adjust the view before redrawing
  o "AAPDIR" directories should not be installed
  o  2html script still fails when css used
  o autoconf 2.57 cannot handle the configure script
  o the gzip plugin doesn't work when $GZIP contains -N
  o the Python interface may leak memory
  o Python interface: can't get the indices from a range object
  o get a warning for the _Xmblen() prototype
  o when using Sun Workshop 'autochdir' isn't set automatically

